pub struct PostgresQueueBackend { /* private fields */ }Implementations
Sourceimpl PostgresQueueBackend
impl PostgresQueueBackend
Sourcepub async fn new(url: &str) -> Result<PostgresQueueBackend, BosonError>
pub async fn new(url: &str) -> Result<PostgresQueueBackend, BosonError>
Connect to PostgreSQL at url.
Errors
Returns an error when the pool cannot connect or schema bootstrap fails.
Sourcepub async fn connect(url: &str) -> Result<PostgresQueueBackend, BosonError>
pub async fn connect(url: &str) -> Result<PostgresQueueBackend, BosonError>
Connect using a PostgreSQL connection URL and wire into Boson.
See crate-level Mode 2 — Enqueue binary and Mode 2 — Worker binary.
Examples
use std::sync::Arc;
use boson_backend_postgres::PostgresQueueBackend;
use boson_core::JsonExecutionContextFactory;
use boson_runtime::Boson;
let url = std::env::var("DATABASE_URL")
.unwrap_or_else(|_| "postgres://localhost/boson".into());
let backend = PostgresQueueBackend::connect(&url).await?;
let _boson = Boson::builder()
.queue_backend(Arc::new(backend))
.execution_context_factory(JsonExecutionContextFactory)
.worker_id("worker-1")
.lease_ttl_secs(30) // Mode 2 multi-process
.auto_registry()
.build()?;Errors
Returns an error when the pool cannot connect or schema bootstrap fails.
Sourcepub async fn connect_isolated(
url: &str,
schema: &str,
) -> Result<PostgresQueueBackend, BosonError>
pub async fn connect_isolated( url: &str, schema: &str, ) -> Result<PostgresQueueBackend, BosonError>
Connect with an isolated schema (for parallel tests).
Errors
Returns an error when schema creation, pool connect, or bootstrap fails.
Sourcepub async fn from_pool(
pool: Pool<Postgres>,
) -> Result<PostgresQueueBackend, BosonError>
pub async fn from_pool( pool: Pool<Postgres>, ) -> Result<PostgresQueueBackend, BosonError>
Wrap an existing pool (schema bootstrap runs).
Errors
Returns an error when schema bootstrap fails.