pub struct SqliteQueueBackend { /* private fields */ }Expand description
Implementations
Sourceimpl SqliteQueueBackend
impl SqliteQueueBackend
Sourcepub async fn new(
path: impl AsRef<Path>,
) -> Result<SqliteQueueBackend, BosonError>
pub async fn new( path: impl AsRef<Path>, ) -> Result<SqliteQueueBackend, BosonError>
Open a SQLite database at path (creates the file if missing).
See crate-level Mode 2 — Enqueue binary and Mode 2 — Worker binary.
Examples
use std::sync::Arc;
use boson_backend_sqlite::SqliteQueueBackend;
use boson_core::JsonExecutionContextFactory;
use boson_runtime::Boson;
let path = std::env::var("BOSON_SQLITE_PATH").unwrap_or_else(|_| "/tmp/boson.db".into());
let backend = SqliteQueueBackend::new(&path).await?;
let _boson = Boson::builder()
.queue_backend(Arc::new(backend))
.execution_context_factory(JsonExecutionContextFactory)
.auto_registry()
.build()?;Errors
Returns an error when the database cannot be opened or schema bootstrap fails.
Sourcepub async fn connect(url: &str) -> Result<SqliteQueueBackend, BosonError>
pub async fn connect(url: &str) -> Result<SqliteQueueBackend, BosonError>
Connect using a SQLite connection URL.
Errors
Returns an error when the pool cannot connect or schema bootstrap fails.
Sourcepub async fn from_pool(
pool: Pool<Sqlite>,
) -> Result<SqliteQueueBackend, BosonError>
pub async fn from_pool( pool: Pool<Sqlite>, ) -> Result<SqliteQueueBackend, BosonError>
Wrap an existing pool (schema bootstrap runs).
Errors
Returns an error when schema bootstrap fails.