pub struct TaskRegistry { /* private fields */ }Expand description
Registry of tasks discovered via inventory (auto_discover) or register.
Prefer BosonBuilder::auto_registry at boot.
Implementations
Sourceimpl TaskRegistry
impl TaskRegistry
Sourcepub fn get_or_err(
&self,
name: &str,
) -> Result<&'static TaskDescriptor, BosonError>
pub fn get_or_err( &self, name: &str, ) -> Result<&'static TaskDescriptor, BosonError>
Look up a task by name, returning an error if not found.
Errors
Returns BosonError::TaskNotFound when the name is absent.
Sourcepub fn sorted_task_names(&self) -> Vec<&str>
pub fn sorted_task_names(&self) -> Vec<&str>
Task names in sorted order.
Sourceimpl TaskRegistry
impl TaskRegistry
pub fn new() -> TaskRegistry
pub fn auto_discover() -> TaskRegistry
pub fn register(&mut self, item: &'static TaskDescriptor)
Methods from Deref<Target = Registry<TaskDescriptor>>
Sourcepub fn register(&mut self, item: &'static T)
pub fn register(&mut self, item: &'static T)
Insert a descriptor. If a descriptor with the same key already exists, it is replaced (last-write-wins).
Sourcepub fn get(&self, key: &str) -> Option<&'static T>
pub fn get(&self, key: &str) -> Option<&'static T>
Look up an item by registry key.
Sourcepub fn iter(&self) -> impl Iterator<Item = &'static T>
pub fn iter(&self) -> impl Iterator<Item = &'static T>
Iterates over all registered descriptors in arbitrary order.